Get the structural params to estimate for nlmer (= saemParamsToEstimate)
Source:R/nlmerRxUiGet.R
rxUiGet.nlmerThetas.RdGet the structural params to estimate for nlmer (= saemParamsToEstimate)
Usage
# S3 method for class 'nlmerThetas'
rxUiGet(x, ...)